import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initAllPlugins()

    waitForObject(":all_plugins.skg - skrooge_KTabBar")
    type(":all_plugins.skg - skrooge_KTabBar", "<Ctrl+Alt+1>")
    waitForObject(":Skrooge monthly plugin.kRefresh_QToolButton")
    clickButton(":Skrooge monthly plugin.kRefresh_QToolButton")
    
    snooze(1)

    waitForObject(":kMonth_SKGComboBox")
    sendEvent("QWheelEvent", ":kMonth_SKGComboBox", 63, 12, -120, 0, 2)
    waitForObject(":kMonth_SKGComboBox")
    sendEvent("QWheelEvent", ":kMonth_SKGComboBox", 63, 12, -120, 0, 2)
    waitForObject(":kMonth_SKGComboBox")
    sendEvent("QWheelEvent", ":kMonth_SKGComboBox", 63, 12, -120, 0, 2)
    waitForObject(":kMonth_SKGComboBox")
    sendEvent("QWheelEvent", ":kMonth_SKGComboBox", 63, 12, -120, 0, 2)
    waitForObject(":Skrooge monthly plugin.kRefresh_QToolButton")
    clickButton(":Skrooge monthly plugin.kRefresh_QToolButton")
    
    snooze(1)
    
    waitForObject(":all_plugins.skg [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":all_plugins.skg [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    clickButton(":Question – Skrooge.Do not save_KPushButton")
    